# Nils Gehlenborg / Nozzle Demo Report / August 2011

require( "Nozzle.R1" );

fhReport1 <- newReport( "Nozzle Demo Report 1" );

fhReport1 <- setMaintainerName( fhReport1, "Nils Gehlenborg" );
fhReport1 <- setMaintainerEmail( fhReport1, "nils@hms.harvard.edu" );
fhReport1 <- setMaintainerAffiliation( fhReport1, "Harvard Medical School" );


# --- Data ---

figureFile <- "figures/image1.jpg";
figureFileHighRes <- "figures/image1_highres.jpg";

tableDataFile <- "files/table_file.txt";
tableData <- read.table( tableDataFile, sep="\t", skip=1, nrows=10, header=TRUE );
tableData[,2] <- as.numeric( tableData[,2] );

gisticDataFile <- "files/scores_.conf_level.99.gistic.txt";
gisticData <- read.table( gisticDataFile, sep="\t", nrows=100, header=TRUE );


# --- References ---

simpleCitation <- newCitation( authors="Nils Gehlenborg", title="The Nozzle Report Package", year="2011", url="http://www.gehlenborg.com" );
webCitation <- newCitation( title="The Cancer Genome Atlas Website", url="http://tcga.cancer.gov/" );
fullCitation <- newCitation( authors="Nils Gehlenborg", title="Nozzle: An R Package for Report Generation", publication="Yet Another Bioinformatics Journal", issue="14", number="44", pages="783-789", year="2011", url="http://www.wikipedia.org" );

fhReport1 <- addToReferences( fhReport1, simpleCitation, webCitation, fullCitation );


# --- Overview ---

fhReport1 <- addToIntroduction( fhReport1,
				newParagraph( "Nozzle is an R Package to generate reports for high-throughput data analysis pipelines based on\
					HTML, CSS and JavaScript. However, ", asEmph( "to use " ), "Nozzle, no knowledge of\
					these technologies is required." ) ); 

fhReport1 <- addToSummary( fhReport1,
				newParagraph( "A simple API that enables developers to design efficient reports quickly." ) );


# --- Results ---

figure1 <- newFigure( figureFile, fileHighRes=figureFileHighRes,
				"An example for a figure. Everything that is shown in the figure should be explained\
				in the caption. The figure needs to have axis labels and a legend." );

figure2 <- newFigure( figureFile,
				"An example for a figure without a link to a high-res file." );
				
table1 <- newTable( tableData, file=tableDataFile, significantDigits=0,				
				"A small table. All ", asParameter( "parameters" ), " shown in the columns\
				of the table need to be explained in the caption." );

mySignificantDigits <- 2;
table3 <- newTable( tableData, significantDigits=mySignificantDigits,
				"A small table without a link to a file. The values in this table have been trimmed to ", mySignificantDigits, " significant digits." );

# to get an empty table with a link to the full table file just pass the colum names
table4 <- newTable( colnames( tableData ), file=tableDataFile,
				"A small table without content but a link to the full table." );
						
table5 <- newTable( gisticData, significantDigits=mySignificantDigits, file=gisticDataFile,
				"A long table (GISTIC 2 output). The values in this table have been trimmed to ", mySignificantDigits, " significant digits." );


paragraph1 <- newParagraph( "Nozzle supports a range of different formatting styles: ",
				asStrong( "strong" ), "; ", 
				asEmph( "emph" ), "; ",
				asParameter( "parameter" ), " = ",
				asValue( "value" ), "; ",
				asFilename( "filename" ), "; ",
				asCode( "code" ), "; " );
				
list <- newList( newParagraph( "Nozzle also provides lists." ),
				newParagraph( "They can even be nested." ),
				newList( isNumbered=TRUE, newParagraph( "They may contain other lists." ),
					newParagraph( "Or selected other elements." ),
					newParagraph( "Numbered." )  ),
				newParagraph( "Or unnumbered." )  );				
			
paragraph2 <- newParagraph( "The Nozzle package ", asReference( simpleCitation ), " also supports referencing of figures, tables and\
					references ", asReference( webCitation ), asReference( fullCitation ), " that are part of the report. For instance, developers can\
					refer to a figure1, such as ", asReference( figure1 ), ", or to a table, such\
					as ", asReference( table1 ), "." );					
					
paragraphPublic <- newParagraph( "Nozzle reports may also contain results with different levels\
					of protection. For instance, this paragraph is labeled ",
					asLink( "\'PUBLIC\'", url="demo1_public_standalone.html" ), " and will be\
					included in all reports. However, the next paragraph is labeled ",
					asLink( "\'GROUP\'", url="demo1_tcga_standalone.html" ), " and will\
					only be included in reports for members of the TCGA Consortium. The paragraph after \
					the next is even more restricted and labeled ",
					asLink( "\'PRIVATE\'", url="demo1_private_standalone.html" ), ", which means that it\
					will only show up in internal reports. ", asStrong( "Please note that if you\
					are viewing the public version or the TCGA/group version of the report you might not\
					see any paragraphs or only one paragraph after this one." ), protection=PROTECTION.PUBLIC );

paragraphTcga <- newParagraph( "This paragraph is protected and will only be included in reports\
					for members of the TCGA Consortium.", protection=PROTECTION.GROUP );

paragraphPrivate <- newParagraph( "This is a private paragraph. Hardly anyone gets to see this.",
					protection=PROTECTION.PRIVATE );
					
result1 <- newResult( asParameter( "A" ), " = ", asValue( "53030" ), isSignificant=round( runif(1) ) );
result1 <- addTo( result1,
		  	 addTo( newSection( "My Rocking Result" ),
				addTo( newSubSection( "My Rocking Subresult" ),
					addTo( newSubSubSection( "My Subrocking Subresult" ),
						newParagraph( "This is a paragraph related to the rocking result of A = 53030.\
							Results may contain all sorts of section, figures, tables, list and so on.\
							But no more results, please!" )
					)
				),
				newFigure( "figures/image2.jpg", fileHighRes="figures/image2_highres.jpg",
					"Symmetry. By Kokorono: ", asLink( url="http://www.flickr.com/photos/kokorono/5422006034" ) )
			 )
		 );

result2 <- newResult( asParameter( "B" ), " = ", asValue( "1234" ), isSignificant=round( runif(1) ) );
result2 <- addTo( result2,
		  	 addTo( newSection( "My Rocking Result" ),			
				newParagraph( "This is a paragraph related to the rocking result of A = 53030.\
					Results may contain all sorts of section, figures, tables, list and so on.\
					But no more results, please!" ),
				newFigure( "figures/image1.jpg", fileHighRes="figures/image1_highres.jpg",
					"Anothr pictur from Flickr." ),
				table5					
			 )
		 );
		 
result3 <- newResult( asParameter( "C" ), " = ", asValue( "Oh no!" ), isSignificant=FALSE );
					
paragraph3 <- newParagraph( "A particularly fun aspect of Nozzle is how it handles results and\
					summaries of results. For instance, we have found that ", asSummary( result1 ),
					", which is totally an amazing result. It is ", if ( result1$isSignificant )  { "totally" } else { "not" }, " significant." );
					
list2 <- newList( newParagraph( "This is another list." ),
				newParagraph( "It contains a result: ", asSummary( result2 ) ),
				newParagraph( "And an empty result: ", asSummary( result3 ) ),
				newParagraph( "That's nice!" )  );				

table2 <- newTable( tableData, file=tableDataFile,				
				"Another small table. This table has result1 summaries associated with it. All ",
				asParameter( "parameters" ), " shown in the columns of the table need to be explained in the caption." );

for ( i in 1:dim( tableData )[1] )
{
	if ( i %% 2 == 0 )
	{	
		result1 <- addTo( newResult( "", isSignificant=( tableData[i,4] < 0.0001 ) ),
			addTo( newSection( "Result ", i ), newParagraph( "This is a paragraph related to ", tableData[i,1], "." ) ) );
	}
	else
	{
		result1 <- newResult( "", isSignificant=( tableData[i,4] < 0.0001 ) );
	}
	table2 <- addTo( table2, result1, row=i, column=4 );
}

fhReport1 <- addToResults( fhReport1,
				addTo( newSubSection( "Nozzle Figure" ), figure1, figure2 ),
				addTo( newSubSection( "Nozzle Table" ), table1, table4, table3, table5 ), 
				addTo( newSubSection( "Nozzle Text" ), paragraph1, list, paragraph2, paragraphPublic,
							paragraphTcga, paragraphPrivate ),
				addTo( newSubSection( "Nozzle Results" ), addTo( newSubSubSection( "Subsubsection!" ),
				newParagraph( "Text in a subsubsection! But the next paragraph belongs to the \"Nozzle Results\" subsection." ) ), paragraph3, list2, table2 ) ); 

				
# --- Methods ---

method1 <- addTo( newSubSection( "Really Cool Method" ),
				newParagraph( "A typical method description consists of one or two paragraphs of\
					text describing the method, followed by a list of method parameters and their\
					values for the present run." ),
				newParameterList( asParameter( "param alpha" ), asValue( "Bet" ),
					asParameter( "param beta" ), asValue( "Carotene" ),
					asParameter( "param gamma" ), asValue( "rays" )) );

method2 <- addTo( newSubSection( "Pretty Fast Method" ), 
				newParagraph( "A typical method description consists of one or two paragraphs of\
					text describing the method, followed by a list of method parameters and their\
					values for the present run." ),
				newParameterList( asParameter( "n" ), asValue( "x" ),
					asParameter( "Q" ), asValue( "1034" ),
					asParameter( "T" ), asValue( "4.4" )) );

fhReport1 <- addToMethods( fhReport1, method1, method2 );

fhReport1 <- addToInput( fhReport1, 
				newParagraph( "This section should list the files that were used as input." ),
				newParameterList( asParameter( "methylation file" ),
					asFilename( "/path/to/this/great/file" ),
					asParameter( "gene expression file" ),
					asFilename( "/path/to/gene/expression/file" ) ) );				


# Report number 2
fhReport2 <- newReport( "Nozzle Demo Report 2" );
fhReport2 <- setNextReport( fhReport2, "demo3_standalone.html", "Demo 3" );
fhReport2 <- setPreviousReport( fhReport2, "demo1_standalone.html", "Demo" );

# Report number 3
fhReport3 <- newReport( "Nozzle Demo Report 3" );
fhReport3 <- setNextReport( fhReport3, "demo1_standalone.html", "Demo" );
fhReport3 <- setPreviousReport( fhReport3, "demo2_standalone.html", "Demo 2" );
fhReport3 <- addToResults( fhReport3, addTo( newSubSection( "Hello World!" ), newParagraph( "This is a test!" ) ) );

fhReport1 <- setNextReport( fhReport1, "demo2_standalone.html", "Demo 2" );
fhReport1 <- setPreviousReport( fhReport1, "demo3_standalone.html", "Demo 3" );

# --- HTML generation ---

writeReport( fhReport1, filename="demo1_public", level=PROTECTION.PUBLIC );
writeReport( fhReport1, filename="demo1_tcga", level=PROTECTION.GROUP );
writeReport( fhReport1, filename="demo1_private", level=PROTECTION.PRIVATE );

writeReport( fhReport1, filename="demo1", level=PROTECTION.PRIVATE );	
writeReport( fhReport2, filename="demo2", level=PROTECTION.PRIVATE );
writeReport( fhReport3, filename="demo3", level=PROTECTION.PRIVATE );

# write a "debug" development version that uses external JS and CSS for more rapid development
#writeReport( fhReport1, filename="demo1", debug=TRUE, level=PROTECTION.PRIVATE,
#	debugCss="/Users/nils/Projects/Firehose/Reports/Nozzle\ Library/Nozzle.R1/inst/css/nozzle.css",
#	debugJavaScript="/Users/nils/Projects/Firehose/Reports/Nozzle\ Library/Nozzle.R1/inst/js/nozzle.js" );

